ArchivoFlutterUtilsModel class

Constructors

ArchivoFlutterUtilsModel(Uint8List bytes, bool soportaCompresion)

Properties

bytes → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soportaCompresion → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited