FlutterUtilsImplementacionCuit class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

generarCUIT({required String dni, required String sexo}) → String
Genera un CUIT a partir de un DNI, intentando con varios prefijos.
validarCUIT(String cuit) → bool
Funcion utilizada para validar un numero de cuit. parametros: